## riskpy
riskpy is a python package with usefull tools for risk analysts, validators and any other people who build and check statistical models

## Installation
### Dependencies

riskpy requires:

Python (>= 2.7 or >= 3.4)
NumPy (>= 1.8.2)
SciPy (>= 0.13.3)
Statsmodels (>= 0.8.0)


## Development

### Important links
Official source code repo: https://github.com/Falconwatch/riskpy
Download releases: unavailable
Issue tracker: https://github.com/Falconwatch/riskpy/issues

### Source code
You can check the latest sources with the command:
git clone https://github.com/Falconwatch/riskpy.git

## Project History
Project was started in 2017

## Help and Support

### Citation
If you use riskpy in a scientific publication, we would appreciate citations
